==> openshift-model-clusterautoscaling-5.12.1-sources.jar: io/fabric8/openshift/api/model/clusterautoscaling/v1/ScaleDownConfigBuilder.java <==
package io.fabric8.openshift.api.model.clusterautoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ScaleDownConfigBuilder extends io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluentImpl<io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig,io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigBuilder>{
  public ScaleDownConfigBuilder() {
    this(false);
  }
  public ScaleDownConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new ScaleDownConfig(), validationEnabled);
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ScaleDownConfig(), validationEnabled);
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluent<?> fluent,io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig instance) {
    this(fluent, instance, false);
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluent<?> fluent,io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDelayAfterAdd(instance.getDelayAfterAdd()); 
    fluent.withDelayAfterDelete(instance.getDelayAfterDelete()); 
    fluent.withDelayAfterFailure(instance.getDelayAfterFailure()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withUnneededTime(instance.getUnneededTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig instance) {
    this(instance,false);
  }
  public ScaleDownConfigBuilder(io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withDelayAfterAdd(instance.getDelayAfterAdd()); 
    this.withDelayAfterDelete(instance.getDelayAfterDelete()); 
    this.withDelayAfterFailure(instance.getDelayAfterFailure()); 
    this.withEnabled(instance.getEnabled()); 
    this.withUnneededTime(instance.getUnneededTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.clusterautoscaling.v1.ScaleDownConfig build() {
    ScaleDownConfig buildable = new ScaleDownConfig(fluent.getDelayAfterAdd(),fluent.getDelayAfterDelete(),fluent.getDelayAfterFailure(),fluent.getEnabled(),fluent.getUnneededTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ScaleDownConfigBuilder that = (ScaleDownConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-clusterautoscaling-6.5.1-sources.jar: io/fabric8/openshift/api/model/clusterautoscaling/v1/ScaleDownConfigBuilder.java <==
package io.fabric8.openshift.api.model.clusterautoscaling.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ScaleDownConfigBuilder extends ScaleDownConfigFluentImpl<ScaleDownConfigBuilder> implements VisitableBuilder<ScaleDownConfig,ScaleDownConfigBuilder>{
  public ScaleDownConfigBuilder() {
    this(false);
  }
  public ScaleDownConfigBuilder(Boolean validationEnabled) {
    this(new ScaleDownConfig(), validationEnabled);
  }
  public ScaleDownConfigBuilder(ScaleDownConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ScaleDownConfigBuilder(ScaleDownConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ScaleDownConfig(), validationEnabled);
  }
  public ScaleDownConfigBuilder(ScaleDownConfigFluent<?> fluent,ScaleDownConfig instance) {
    this(fluent, instance, false);
  }
  public ScaleDownConfigBuilder(ScaleDownConfigFluent<?> fluent,ScaleDownConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withDelayAfterAdd(instance.getDelayAfterAdd()); 
    fluent.withDelayAfterDelete(instance.getDelayAfterDelete()); 
    fluent.withDelayAfterFailure(instance.getDelayAfterFailure()); 
    fluent.withEnabled(instance.getEnabled()); 
    fluent.withUnneededTime(instance.getUnneededTime()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ScaleDownConfigBuilder(ScaleDownConfig instance) {
    this(instance,false);
  }
  public ScaleDownConfigBuilder(ScaleDownConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withDelayAfterAdd(instance.getDelayAfterAdd()); 
    this.withDelayAfterDelete(instance.getDelayAfterDelete()); 
    this.withDelayAfterFailure(instance.getDelayAfterFailure()); 
    this.withEnabled(instance.getEnabled()); 
    this.withUnneededTime(instance.getUnneededTime()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ScaleDownConfigFluent<?> fluent;
  Boolean validationEnabled;
  public ScaleDownConfig build() {
    ScaleDownConfig buildable = new ScaleDownConfig(fluent.getDelayAfterAdd(),fluent.getDelayAfterDelete(),fluent.getDelayAfterFailure(),fluent.getEnabled(),fluent.getUnneededTime());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
